#define IMAGES_DIR "/usr/share/pixmaps/"
GtkWidget *main_window, *vbox1;
GtkWidget *table1;
GtkWidget *buttons[15];
GtkWidget *statusbar1;
GtkWidget *alignment1;
GtkWidget *image;

gint move_no;
gint vacant_pos;


GtkWidget*
create_main_window (void);

void
swap_buttons (int p, int q);

void
on_new_activate (GtkMenuItem *menuitem, gpointer         user_data);

void
on_open1_activate (GtkMenuItem *menuitem, gpointer         user_data);

void
on_save1_activate (GtkMenuItem *menuitem, gpointer         user_data);

void
on_save_as1_activate (GtkMenuItem *menuitem, gpointer         user_data);

void
on_quit1_activate (GtkMenuItem *menuitem, gpointer         user_data);

void
on_cut1_activate (GtkMenuItem *menuitem, gpointer         user_data);

void
on_copy1_activate (GtkMenuItem *menuitem, gpointer         user_data);

void
on_paste1_activate (GtkMenuItem *menuitem, gpointer         user_data);

void
on_delete1_activate (GtkMenuItem *menuitem, gpointer         user_data);

void
on_about1_activate (GtkMenuItem *menuitem, gpointer         user_data);
